@@ -1,7 +1,9 @@
-# $Id: ASN.pm,v 1.4 2001/04/10 16:30:27 gbarr Exp $
+# $Id: ASN.pm,v 1.6 2003/04/07 15:05:12 gbarr Exp $
 
 package Net::LDAP::ASN;
 
+$VERSION = "0.02";
+
 use Convert::ASN1;
 
 my $asn = Convert::ASN1->new;
@@ -292,8 +294,8 @@ $asn->prepare(<<LDAP_ASN) or die $asn->error;
 	   beforeCount    INTEGER , --(0 .. maxInt),
 	   afterCount     INTEGER , --(0 .. maxInt),
 	   CHOICE {
-	       byIndex [0] SEQUENCE {
-	       index           INTEGER , --(0 .. maxInt),
+	       byoffset [0] SEQUENCE {
+	       offset          INTEGER , --(0 .. maxInt),
 	       contentCount    INTEGER } --(0 .. maxInt) }
 	       byValue [1] AssertionValue }
 	       -- byValue [1] greaterThanOrEqual assertionValue }
@@ -312,7 +314,8 @@ $asn->prepare(<<LDAP_ASN) or die $asn->error;
 	       adminLimitExceeded (11),
 	       sortControlMissing (60),
 	       indexRangeError (61),
-	       other (80) }  }
+	       other (80) }  
+	   contextID     OCTET STRING OPTIONAL     }
 
 
     LDAPEntry ::= COMPONENTS OF AddRequest
