@@ -1,4 +1,4 @@
-# $Id: Sort.pm,v 1.5 2000/09/12 09:17:09 gbarr Exp $
+# $Id: Sort.pm,v 1.7 2003/05/07 11:55:22 chrisridd Exp $
 # Copyright (c) 1999-2000 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -9,7 +9,7 @@ use vars qw(@ISA $VERSION);
 use Net::LDAP::Control;
 
 @ISA = qw(Net::LDAP::Control);
-$VERSION = "0.01";
+$VERSION = "0.02";
 
 use Net::LDAP::ASN qw(SortRequest);
 use strict;
@@ -132,13 +132,13 @@ Net::LDAP::Control::Sort - Server Side Sort (SSS) control object
 =head1 DESCRIPTION
 
 C<Net::LDAP::Control::Sort> is a sub-class of
-L<Net::LDAP::Control|Net::LDAP::Control>.  It provides a class
+L<Net::LDAP::Control>.  It provides a class
 for manipulating the LDAP Server Side Sort (SSS) request control
 C<1.2.840.113556.1.4.473> as defined in RFC-2891
 
 If the server supports sorting, then the response from a search
 operation will include a sort result control. This control is handled
-by L<Net::LDAP::Control::SortResult|Net::LDAP::Control::SortResult>.
+by L<Net::LDAP::Control::SortResult>.
 
 =head1 CONSTRUCTOR ARGUMENTS
 
@@ -173,24 +173,24 @@ B<Examples>
 
 =head1 METHODS
 
-As with L<Net::LDAP::Control|Net::LDAP::Control> each constructor argument
-described above is also avaliable as a method on the object which will
+As with L<Net::LDAP::Control> each constructor argument
+described above is also available as a method on the object which will
 return the current value for the attribute if called without an argument,
 and set a new value for the attribute if called with an argument.
 
 =head1 SEE ALSO
 
-L<Net::LDAP|Net::LDAP>,
-L<Net::LDAP::Control::SortResult|Net::LDAP::Control::SortResult>,
-L<Net::LDAP::Control|Net::LDAP::Control>,
-http://info.internet.isi.edu/in-notes/rfc/files/rfc2891.txt
+L<Net::LDAP>,
+L<Net::LDAP::Control::SortResult>,
+L<Net::LDAP::Control>,
+http://www.ietf.org/rfc/rfc2891.txt
 
 =head1 AUTHOR
 
-Graham Barr <gbarr@pobox.com>
+Graham Barr E<lt>gbarr@pobox.comE<gt>
 
 Please report any bugs, or post any suggestions, to the perl-ldap mailing list
-<perl-ldap-dev@lists.sourceforge.net>
+E<lt>perl-ldap@perl.orgE<gt>
 
 =head1 COPYRIGHT
 
@@ -200,6 +200,6 @@ terms as Perl itself.
 
 =for html <hr>
 
-I<$Id: Sort.pm,v 1.5 2000/09/12 09:17:09 gbarr Exp $>
+I<$Id: Sort.pm,v 1.7 2003/05/07 11:55:22 chrisridd Exp $>
 
 =cut
