@@ -1,4 +1,4 @@
-# $Id: SortResult.pm,v 1.5 2001/08/24 19:31:14 gbarr Exp $
+# $Id: SortResult.pm,v 1.6 2003/05/07 11:56:48 chrisridd Exp $
 # Copyright (c) 1999-2000 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -156,14 +156,14 @@ a definition of each.
 L<Net::LDAP>,
 L<Net::LDAP::Control::Sort>,
 L<Net::LDAP::Control>,
-http://info.internet.isi.edu/in-notes/rfc/files/rfc2891.txt
+http://ww.ietf.org/rfc/rfc2891.txt
 
 =head1 AUTHOR
 
-Graham Barr <gbarr@pobox.com>
+Graham Barr E<lt>gbarr@pobox.comE<gt>
 
 Please report any bugs, or post any suggestions, to the perl-ldap mailing list
-<perl-ldap-dev@lists.sourceforge.net>
+E<lt>perl-ldap@perl.orgE<gt>
 
 =head1 COPYRIGHT
 
@@ -173,6 +173,6 @@ terms as Perl itself.
 
 =for html <hr>
 
-I<$Id: SortResult.pm,v 1.5 2001/08/24 19:31:14 gbarr Exp $>
+I<$Id: SortResult.pm,v 1.6 2003/05/07 11:56:48 chrisridd Exp $>
 
 =cut
